@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-"""Simplified Twisted Deferreds."""
+"""Small framework for asynchronous programming."""
 # Copyright (C) 2008-2010 Sebastian Heinlein <devel@glatzor.de>
 # Copyright (c) 2001-2010
 # Allen Short
@@ -65,10 +65,11 @@ __author__  = "Sebastian Heinlein <devel@glatzor.de>"
 __all__ = ("Deferred", "AlreadyCalledDeferred", "DeferredException",
            "defer", "inline_callbacks", "return_value")
 
-__version__ = 1.0
+__version__ = "1.0.1"
 
 from functools import wraps
 import sys
+import warnings
 
 
 class _DefGen_Return(BaseException):
@@ -177,27 +178,27 @@ class Deferred(object):
     by the errback of the next pair. If an errback doesn't raise an error
     again, the callback of the next pair will be called with the return
     value of the errback. Otherwise the exception of the errback will be
-    returned to the errback of the next pair.
+    returned to the errback of the next pair::
 
-      CALLBACK1      ERRBACK1
-       |     \       /     |
-   result failure  result failure
-       |       \   /       |
-       |        \ /        |
-       |         X         |
-       |        / \        |
-       |       /   \       |
-       |      /     \      |
-      CALLBACK2      ERRBACK2
-       |     \       /     |
-   result failure  result failure
-       |       \   /       |
-       |        \ /        |
-       |         X         |
-       |        / \        |
-       |       /   \       |
-       |      /     \      |
-      CALLBACK3      ERRBACK3
+        CALLBACK1      ERRBACK1
+         |     \       /     |
+     result failure  result failure
+         |       \   /       |
+         |        \ /        |
+         |         X         |
+         |        / \        |
+         |       /   \       |
+         |      /     \      |
+        CALLBACK2      ERRBACK2
+         |     \       /     |
+     result failure  result failure
+         |       \   /       |
+         |        \ /        |
+         |         X         |
+         |        / \        |
+         |       /   \       |
+         |      /     \      |
+        CALLBACK3      ERRBACK3
       """
 
     def __init__(self):
@@ -496,7 +497,7 @@ def _inline_callbacks(result, gen, deferred):
             # directly.  returnValue itself consumes a stack frame, so the
             # application code will have a tb_next, but it will *not* have a
             # second tb_next.
-            if appCodeTrace.tb_next.tb_next:
+            if appCodeTrace.tb_next and appCodeTrace.tb_next.tb_next:
                 # If returnValue was invoked non-local to the frame which it is
                 # exiting, identify the frame that ultimately invoked
                 # returnValue so that we can warn the user, as this behavior is
@@ -546,7 +547,7 @@ def _inline_callbacks(result, gen, deferred):
 
 def inline_callbacks(func):
     """inline_callbacks helps you write Deferred-using code that looks like a
-    regular sequential function. For example:
+    regular sequential function. For example::
 
         def thingummy():
             thing = yield makeSomeRequestResultingInDeferred()
@@ -566,7 +567,7 @@ def inline_callbacks(func):
     will cause the Deferred to have a result of None.
 
     The Deferred returned from your deferred generator may errback if your
-    generator raised an exception:
+    generator raised an exception::
 
         def thingummy():
             thing = yield makeSomeRequestResultingInDeferred()
